You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by ju...@apache.org on 2005/04/19 19:24:25 UTC

svn commit: r161924 - in incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi: client/ remote/ server/ xml/

Author: jukka
Date: Tue Apr 19 10:24:23 2005
New Revision: 161924

URL: http://svn.apache.org/viewcvs?view=rev&rev=161924
Log:
JCR-97: Checkstyle conformance fixes for JCR-RMI.

Modified:
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientQuery.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientSession.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientVersion.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteLock.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteNode.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteQuery.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteSession.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteVersionHistory.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/server/ServerLock.java
    incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/xml/SessionImportContentHandler.java

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientQuery.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientQuery.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientQuery.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientQuery.java Tue Apr 19 10:24:23 2005
@@ -20,14 +20,7 @@
 
 import javax.jcr.RepositoryException;
 import javax.jcr.Session;
-import javax.jcr.ItemNotFoundException;
 import javax.jcr.Node;
-import javax.jcr.ItemExistsException;
-import javax.jcr.PathNotFoundException;
-import javax.jcr.UnsupportedRepositoryOperationException;
-import javax.jcr.lock.LockException;
-import javax.jcr.nodetype.ConstraintViolationException;
-import javax.jcr.version.VersionException;
 import javax.jcr.query.Query;
 import javax.jcr.query.QueryResult;
 

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientSession.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientSession.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientSession.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientSession.java Tue Apr 19 10:24:23 2005
@@ -207,7 +207,7 @@
 
     /** {@inheritDoc} */
     public void checkPermission(String path, String actions)
-            throws AccessControlException, RepositoryException{
+            throws AccessControlException, RepositoryException {
         try {
             remote.checkPermission(path, actions);
         } catch (RemoteException ex) {

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientVersion.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientVersion.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientVersion.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/client/ClientVersion.java Tue Apr 19 10:24:23 2005
@@ -81,7 +81,7 @@
         }
     }
 
-    /** {@inheritDoc */
+    /** {@inheritDoc} */
     public VersionHistory getContainingHistory() throws RepositoryException {
         try {
             return getFactory().getVersionHistory(getSession(), remote.getContainingHistory());

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteLock.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteLock.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteLock.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteLock.java Tue Apr 19 10:24:23 2005
@@ -74,6 +74,7 @@
      *
      * @return <code>true</code> if the lock is live,
      *         <code>false</code> otherwise
+     * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      */
     boolean isLive() throws RepositoryException, RemoteException;

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteNode.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteNode.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteNode.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteNode.java Tue Apr 19 10:24:23 2005
@@ -20,8 +20,6 @@
 
 import javax.jcr.RepositoryException;
 import javax.jcr.Value;
-import javax.jcr.NodeIterator;
-
 
 /**
  * Remote version of the JCR {@link javax.jcr.Node Node} interface.
@@ -401,6 +399,7 @@
      *
      * @param workspace source workspace name
      * @param bestEffort best effort flag
+     * @return nodes that failed to merge
      * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      */

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteQuery.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteQuery.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteQuery.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteQuery.java Tue Apr 19 10:24:23 2005
@@ -20,7 +20,6 @@
 import java.rmi.RemoteException;
 
 import javax.jcr.RepositoryException;
-import javax.jcr.Node;
 
 /**
  * Remote version of the JCR {@link javax.jcr.query.Query Query} interface.
@@ -75,6 +74,7 @@
      * @see javax.jcr.query.Query#storeAsNode(String)
      *
      * @param absPath path at which to persist this query.
+     * @return stored node
      * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      */

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteSession.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteSession.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteVersionHistory.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteVersionHistory.java Tue Apr 19 10:24:23 2005
@@ -142,6 +142,7 @@
      *
      * @param label a version label
      * @return a <code>boolean</code>
+     * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      */
     boolean hasVersionLabel(String label) throws RepositoryException, RemoteException;
@@ -166,6 +167,7 @@
      * method.
      *
      * @return a <code>String</code> array containing all the labels of the version history
+     * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      */
     String[] getVersionLabels() throws RepositoryException, RemoteException;

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/server/ServerLock.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/server/ServerLock.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/server/ServerLock.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/server/ServerLock.java Tue Apr 19 10:24:23 2005
@@ -74,6 +74,7 @@
         lock.refresh();
     }
 
+    /** {@inheritDoc} */
     public boolean isSessionScoped() throws RemoteException {
         return lock.isSessionScoped();
     }

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/xml/SessionImportContentHandler.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/xml/SessionImportContentHandler.java?view=diff&r1=161923&r2=161924
==============================================================================
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/xml/SessionImportContentHandler.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/xml/SessionImportContentHandler.java Tue Apr 19 10:24:23 2005
@@ -48,11 +48,13 @@
      *
      * @param session repository session
      * @param path import content path
+     * @param uuidBehaviour UUID behaviour mode
      */
-    public SessionImportContentHandler(Session session, String path, int mode) {
+    public SessionImportContentHandler(
+            Session session, String path, int uuidBehaviour) {
         this.session = session;
         this.path = path;
-        this.mode = mode;
+        this.mode = uuidBehaviour;
     }
 
     /**
--- incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteSession.java (original)
+++ incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteSession.java Tue Apr 19 10:24:23 2005
@@ -137,6 +137,7 @@
      * @param path item path
      * @return <code>true</code> if the item exists,
      *         <code>false</code> otherwise
+     * @throws RepositoryException on repository exception
      * @throws RemoteException on RMI errors
      */
     boolean itemExists(String path) throws RepositoryException, RemoteException;
@@ -186,10 +187,11 @@
 
     /**
      * Remote version of the
-     * {@link javax.jcr.Session#isLive()} Session.isLive()}
+     * {@link javax.jcr.Session#isLive() Session.isLive()}
      * method.
-     * @return
      *
+     * @return <code>true</code> if the session is live,
+     *         <code>false</code> otherwise
      * @throws RemoteException on RMI errors
      */
     boolean isLive() throws RemoteException;
@@ -224,6 +226,7 @@
      * @param path item path
      * @param actions actions
      * @throws AccessControlException if permission is denied
+     * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      */
     void checkPermission(String path, String actions)
@@ -239,12 +242,13 @@
      *
      * @param path node path
      * @param xml imported XML document
+     * @param uuidBehaviour UUID handling mode
      * @throws IOException on IO errors
      * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      * @see javax.jcr.Session#importXML(java.lang.String, java.io.InputStream, int)
      */
-    void importXML(String path, byte[] xml, int mode)
+    void importXML(String path, byte[] xml, int uuidBehaviour)
             throws IOException, RepositoryException, RemoteException;
 
     /**
@@ -336,15 +340,15 @@
      * the XML data written by the normal exportSysView method.
      *
      * @param path node path
      * @param binaryAsLink TODO
      * @param noRecurse TODO
      * @return exported XML document
      * @throws IOException on IO errors
      * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      * @see javax.jcr.Session#exportSystemView
      */
-    byte[] exportSystemView(String path, boolean binaryAsLink, boolean noRecurse)
+    byte[] exportSystemView(String path, boolean skipBinary, boolean noRecurse)
             throws IOException, RepositoryException, RemoteException;
 
     /**
@@ -356,15 +360,15 @@
      * the XML data written by the normal exportDocView method.
      *
      * @param path node path
      * @param binaryAsLink TODO
      * @param noRecurse TODO
      * @return exported XML document
      * @throws IOException on IO errors
      * @throws RepositoryException on repository errors
      * @throws RemoteException on RMI errors
      * @see javax.jcr.Session#exportDocumentView
      */
-    byte[] exportDocumentView(String path, boolean binaryAsLink, boolean noRecurse)
+    byte[] exportDocumentView(String path, boolean skipBinary, boolean noRecurse)
         throws IOException, RepositoryException, RemoteException;
 
 }
@@ -336,15 +340,15 @@
      *
      * @param path node path
-     * @param binaryAsLink TODO
-     * @param noRecurse TODO
+     * @param skipBinary binary skip flag
+     * @param noRecurse no recursion flag
      * @return exported XML document
      * @throws IOException on IO errors
@@ -356,15 +360,15 @@
      *
      * @param path node path
-     * @param binaryAsLink TODO
-     * @param noRecurse TODO
+     * @param skipBinary skip binary flag
+     * @param noRecurse no recursion flag
      * @return exported XML document
      * @throws IOException on IO errors

Modified: incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteVersionHistory.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/contrib/jcr-rmi/src/java/org/apache/jackrabbit/rmi/remote/RemoteVersionHistory.java?view=diff&r1=161923&r2=161924
==============================================================================